@@ -4,4 +4,5 @@
 ((nil . ((tab-width . 8)
          (fill-column . 78)
          (sentence-end-double-space . t)))
- (lisp-mode . ((indent-tabs-mode . nil))))
+ (lisp-mode . ((indent-tabs-mode . nil)))
+ (auto-mode-alist . (("\\.lisp\\'" . consfigurator-lisp-mode))))
