@@ -395,8 +395,8 @@ UIOP:WITH-CURRENT-DIRECTORY."
            for k = (string-upcase (symbol-name (pop env)))
            for v = (pop env)
            if v
-             collect (format nil "export ~A=~A" k (sh-escape v))
-               into accum
+             collect (format nil "~A=~A" k (sh-escape v)) into accum
+             and collect (format nil "export ~A" k) into accum
            else
              collect (format nil "unset -v ~A" k) into accum
            finally
@@ -417,7 +417,7 @@ UIOP:WITH-CURRENT-DIRECTORY."
      ;; implementations of connection types which actually require it for
      ;; simplicity, particularly to avoid having to check whether the connattr
      ;; is set yet, because setting it requires working CONNECTION-RUN.
-     (setq cmd (format nil "export HOME=~A; cd ~A; ~A"
+     (setq cmd (format nil "HOME=~A; export HOME; cd ~A; ~A"
                        (sh-escape (drop-trailing-slash
                                    (unix-namestring
                                     (get-connattr :remote-home))))
@@ -537,24 +537,24 @@ subclass to the :HOSTATTRS subroutine of properties calling this."
     (mrun (format nil "rm -rf -- ~A/* ~A/.[!.]* ~A/..?*" it it it))))
 
 (defun remote-test-multiple (operator paths connective)
-  (apply #'remote-test (loop for path on paths
-                             nconc (list operator (car path))
-                             when (cdr path) collect connective)))
+  (zerop (mrun :for-exit
+               (format nil #?"~{[ ${operator} ~A ]~^ ${connective} ~}"
+                       (mapcar #'sh-escape paths)))))
 
 (defun remote-exists-p (&rest paths)
   "Does each of PATHS exist?
 PATH may be any kind of file, including directories."
-  (remote-test-multiple "-e" paths "-a"))
+  (remote-test-multiple "-e" paths "&&"))
 
 (defun remote-exists-every-p (&rest paths)
   "Does each of PATHS exist?
 PATH may be any kind of file, including directories."
-  (remote-test-multiple "-e" paths "-a"))
+  (remote-test-multiple "-e" paths "&&"))
 
 (defun remote-exists-some-p (&rest paths)
   "Do any of PATHS exist?
 PATH may be any kind of file, including directories."
-  (remote-test-multiple "-e" paths "-o"))
+  (remote-test-multiple "-e" paths "||"))
 
 (defun remote-file-stats (path)
   "Get the numeric mode, size in bytes, mtime, owner and group of PATH, or NIL if
