@@ -37,6 +37,8 @@
                                         :APT_LISTCHANGES_FRONTEND "none")
   :test #'equal)
 
+(defconstant +dpkg-lock-timeout+ 60)
+
 
 ;;;; Properties
 
@@ -183,13 +185,18 @@ E.g. (APT:SERVICE-INSTALLED-RUNNING \"apache2\")."
 (defproplist updated :posix ()
   "Ensure the apt indexes are up-to-date."
   (:desc "apt-get update")
-  (all-configured)
-  (os:etypecase
-    (debian-stable
-     (cmd:single :env +noninteractive-env+ :inform "apt-get" "update"))
-    (debian
-     (cmd:single :env +noninteractive-env+ :inform
-                 "apt-get" "update" "--allow-releaseinfo-change"))))
+  (seqprops
+   (all-configured)
+   (os:etypecase
+     (debian-stable
+      (cmd:single :env +noninteractive-env+ :inform "apt-get"
+                  "-o" #?"DPkg::Lock::Timeout=${+dpkg-lock-timeout+}"
+                  "update"))
+     (debian
+      (cmd:single :env +noninteractive-env+ :inform
+                  "apt-get"
+                  "-o" #?"DPkg::Lock::Timeout=${+dpkg-lock-timeout+}"
+                  "update" "--allow-releaseinfo-change")))))
 
 (defprop upgraded :posix ()
   (:desc "apt upgraded")
@@ -468,4 +475,5 @@ installed."
 ;;;; Utilities
 
 (defun apt-get (&rest args)
-  (apply #'run :env +noninteractive-env+ "apt-get" args))
+  (apply #'run :env +noninteractive-env+
+         "apt-get" "-o" #?"DPkg::Lock::Timeout=${+dpkg-lock-timeout+}" args))
