@@ -13,7 +13,7 @@
 ;;; GNU General Public License for more details.
 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (in-package :consfigurator)
 (named-readtables:in-readtable :consfigurator)
@@ -38,37 +38,6 @@
              for result in new and i upfrom 0 do
                (setf (aref results i) (nreconc result (aref results i))))))
 
-(defun lines (text &optional trimfun (trimchars '(#\Space #\Tab)))
-  (with-input-from-string (stream text)
-    (let (bolp buffer)
-      (flet ((trim (line)
-               (if trimfun (funcall trimfun trimchars line) line))
-             (reset ()
-               (setq bolp t
-                     buffer (make-array 0 :fill-pointer 0
-                                          :element-type 'character))))
-        ;; Split on either <CR>, <LF> or <CR><LF>; <LF><CR> would mean split
-        ;; with a blank line in between.  Drop a single trailing blank line.
-        (loop initially (reset)
-              for char = (read-char stream nil nil)
-              if char
-                if (member char '(#\Return #\Newline) :test #'char=)
-                  collect (trim buffer)
-                  and do (reset)
-                         (when (char= char #\Return)
-                           (when-let ((next (peek-char nil stream nil nil)))
-                             (when (char= next #\Newline)
-                               (read-char stream))))
-                else do (setq bolp nil)
-                        (vector-push-extend char buffer)
-                end
-              else
-                unless bolp collect (trim buffer) end
-                and do (loop-finish))))))
-
-(defun unlines (lines)
-  (format nil "~{~A~%~}" lines))
-
 (defun words (text)
   (delete "" (split-string text) :test #'string=))
 
@@ -280,9 +249,20 @@ simple collections of readably-printable values."
 
 (defun parse-username-from-id (output)
   "Where OUTPUT is the output of the id(1) command, extract the username."
-  (multiple-value-bind (match groups)
-      (re:scan-to-strings "^uid=[0-9]+\\(([^)]+)" output)
-    (and match (elt groups 0))))
+  (#1~/^uid=[0-9]+\(([^)]+)/ output))
+
+(defun abbreviate-consfigurator-package (name)
+  (with-standard-io-syntax
+    (let* ((*package* (find-package :consfigurator))
+           (name (etypecase name
+                   (string name)
+                   (package (package-name name))
+                   (symbol (prin1-to-string name)))))
+      (cond ((string-prefix-p "CONSFIGURATOR.PROPERTY." name)
+             (subseq name 23))
+            ((string-prefix-p "CONSFIGURATOR.DATA." name)
+             (subseq name 14))
+            (t name)))))
 
 ;; not DEFCONSFIG because a consfig is a system not a package
 (defmacro defpackage-consfig (name &body forms)
@@ -295,12 +275,10 @@ expansion as a starting point for your own DEFPACKAGE form for your consfig."
           (cons :local-nicknames
                 (loop for package in (list-all-packages)
                       for name = (package-name package)
-                      if (string-prefix-p "CONSFIGURATOR.PROPERTY." name)
-                        collect (list (make-symbol (subseq name 23))
-                                      (make-symbol name))
-                      else if (string-prefix-p "CONSFIGURATOR.DATA." name)
-                             collect (list (make-symbol (subseq name 14))
-                                           (make-symbol name))))))
+                      for abbrevd = (abbreviate-consfigurator-package name)
+                      unless (string= abbrevd name)
+                        collect (list (make-symbol abbrevd)
+                                      (make-symbol name))))))
     (if-let ((form (loop for form on forms
                          when (and (listp (car form))
                                    (eql :local-nicknames (caar form)))
@@ -355,6 +333,11 @@ expansion as a starting point for your own DEFPACKAGE form for your consfig."
                                        else do (princ #\: s)
                                                (loop-finish)))))))))
 
+(defun try-parse-number (string &rest args &key &allow-other-keys)
+  (and string
+       (handler-case (apply #'parse-number string args)
+         (parse-error () string))))
+
 (eval-when (:compile-toplevel :load-toplevel :execute)
   (define-constant +alphanum+
     "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
@@ -441,11 +424,9 @@ on simple scripts embedded in source code, written with newlines for the sake
 of maintainability.  Converting those scripts to single lines before they are
 executed improves Consfigurator's debug output, and also makes process names
 visible to remote commands like ps(1) more readable."
-  (re:regex-replace-all
-   #?/\s+/ (re:regex-replace-all "(then|else|elif|fi|case|in|;;|do|done);"
-                                 (format nil "~{~A~^; ~}" (lines script))
-                                 "\\1")
-   " "))
+  (#~s/\s+/ /g
+   (#~s/(then|else|elif|fi|case|in|;;|do|done);/\1/g
+    (format nil "~{~A~^; ~}" (lines script)))))
 
 
 ;;;; Progress & debug printing
